@@ -10,7 +10,8 @@ export function parseData(sceneData, actions, catalog) {
     unit: sceneData.unit,
     layers: {},
     width: sceneData.width,
-    height: sceneData.height
+    height: sceneData.height,
+    LODs: {}
   };
 
   planData.plan = new Three.Object3D();
@@ -70,7 +71,6 @@ function createLayerObjects(layer, planData, sceneData, actions, catalog) {
 
 export function updateScene(planData, sceneData, oldSceneData, diffArray, actions, catalog) {
 
-  console.log(diffArray, minimizeChangePropertiesDiffs(diffArray));
   minimizeChangePropertiesDiffs(diffArray).forEach(function (diff) {
 
     /* First of all I need to find the object I need to update */
@@ -256,6 +256,8 @@ function removeHole(planData, layerId, holeToRemoveID) {
   planData.plan.remove(holeToRemove);
   disposeObject(holeToRemove);
   delete planData.sceneGraph.layers[layerId].holes[holeToRemoveID];
+  delete planData.sceneGraph.LODs[holeToRemoveID];
+
   holeToRemove = null;
   updateBoundingBox(planData);
 }
@@ -265,6 +267,7 @@ function removeLine(planData, layerId, lineID) {
   planData.plan.remove(line3D);
   disposeObject(line3D);
   delete planData.sceneGraph.layers[layerId].lines[lineID];
+  delete planData.sceneGraph.LODs[lineID];
   line3D = null;
   updateBoundingBox(planData);
 }
@@ -274,6 +277,7 @@ function removeArea(planData, layerId, areaID) {
   planData.plan.remove(area3D);
   disposeObject(area3D);
   delete planData.sceneGraph.layers[layerId].areas[areaID];
+  delete planData.sceneGraph.LODs[areaID];
   area3D = null;
   updateBoundingBox(planData);
 }
@@ -283,6 +287,7 @@ function removeItem(planData, layerId, itemID) {
   planData.plan.remove(item3D);
   disposeObject(item3D);
   delete planData.sceneGraph.layers[layerId].items[itemID];
+  delete planData.sceneGraph.LODs[itemID];
   item3D = null;
   updateBoundingBox(planData);
 }
@@ -322,6 +327,10 @@ function addHole(sceneData, planData, layer, holeID, catalog, holesActions) {
   // Create the hole object
   return catalog.getElement(holeData.type).render3D(holeData, layer, sceneData).then(function (object) {
 
+    if (object instanceof Three.LOD) {
+      planData.sceneGraph.LODs[holeID] = object;
+    }
+
     var pivot = new Three.Object3D();
     pivot.add(object);
 
@@ -381,6 +390,10 @@ function addLine(sceneData, planData, layer, lineID, catalog, linesActions) {
 
   return catalog.getElement(line.type).render3D(line, layer, sceneData).then(function (line3D) {
 
+    if (line3D instanceof Three.LOD) {
+      planData.sceneGraph.LODs[line.id] = line3D;
+    }
+
     var pivot = new Three.Object3D();
     pivot.add(line3D);
 
@@ -408,6 +421,11 @@ function addArea(sceneData, planData, layer, areaID, catalog, areaActions) {
   };
 
   return catalog.getElement(area.type).render3D(area, layer, sceneData).then(function (area3D) {
+
+    if (area3D instanceof Three.LOD) {
+      planData.sceneGraph.LODs[areaID] = area3D;
+    }
+
     var pivot = new Three.Object3D();
     pivot.add(area3D);
     pivot.position.y = layer.altitude;
@@ -427,6 +445,10 @@ function addItem(sceneData, planData, layer, itemID, catalog, itemsActions) {
 
   return catalog.getElement(item.type).render3D(item, layer, sceneData).then(function (item3D) {
 
+    if (item3D instanceof Three.LOD) {
+      planData.sceneGraph.LODs[itemID] = item3D;
+    }
+
     var pivot = new Three.Object3D();
     pivot.add(item3D);
 
