@@ -10,7 +10,8 @@ function _possibleConstructorReturn(self, call) { if (!self) { throw new Referen
 
 function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }
 
-import React, { PropTypes, Component } from 'react';
+import React, { Component } from 'react';
+import PropTypes from 'prop-types';
 import { bindActionCreators } from 'redux';
 import { connect } from 'react-redux';
 
@@ -98,6 +99,7 @@ ReactPlanner.propTypes = {
   height: PropTypes.number.isRequired,
   stateExtractor: PropTypes.func.isRequired,
   toolbarButtons: PropTypes.array,
+  sidebarComponents: PropTypes.array,
   customContents: PropTypes.object
 };
 
@@ -119,6 +121,7 @@ ReactPlanner.defaultProps = {
   allowProjectFileSupport: true,
 
   toolbarButtons: [],
+  sidebarComponents: [],
   customContents: {}
 };
 
