@@ -10,7 +10,8 @@ export function parseData(sceneData, actions, catalog) {
     unit: sceneData.unit,
     layers: {},
     width: sceneData.width,
-    height: sceneData.height
+    height: sceneData.height,
+    LODs: {}
   };
 
   planData.plan = new Three.Object3D();
@@ -70,7 +71,6 @@ function createLayerObjects(layer, planData, sceneData, actions, catalog) {
 
 export function updateScene(planData, sceneData, oldSceneData, diffArray, actions, catalog) {
 
-  console.log(diffArray, minimizeChangePropertiesDiffs(diffArray));
   minimizeChangePropertiesDiffs(diffArray).forEach(diff => {
 
     /* First of all I need to find the object I need to update */
@@ -245,6 +245,8 @@ function removeHole(planData, layerId, holeToRemoveID) {
   planData.plan.remove(holeToRemove);
   disposeObject(holeToRemove);
   delete planData.sceneGraph.layers[layerId].holes[holeToRemoveID];
+  delete planData.sceneGraph.LODs[holeToRemoveID];
+
   holeToRemove = null;
   updateBoundingBox(planData);
 }
@@ -254,6 +256,7 @@ function removeLine(planData, layerId, lineID) {
   planData.plan.remove(line3D);
   disposeObject(line3D);
   delete planData.sceneGraph.layers[layerId].lines[lineID];
+  delete planData.sceneGraph.LODs[lineID];
   line3D = null;
   updateBoundingBox(planData);
 }
@@ -263,6 +266,7 @@ function removeArea(planData, layerId, areaID) {
   planData.plan.remove(area3D);
   disposeObject(area3D);
   delete planData.sceneGraph.layers[layerId].areas[areaID];
+  delete planData.sceneGraph.LODs[areaID];
   area3D = null;
   updateBoundingBox(planData);
 }
@@ -272,6 +276,7 @@ function removeItem(planData, layerId, itemID) {
   planData.plan.remove(item3D);
   disposeObject(item3D);
   delete planData.sceneGraph.layers[layerId].items[itemID];
+  delete planData.sceneGraph.LODs[itemID];
   item3D = null;
   updateBoundingBox(planData);
 }
@@ -311,6 +316,10 @@ function addHole(sceneData, planData, layer, holeID, catalog, holesActions) {
   // Create the hole object
   return catalog.getElement(holeData.type).render3D(holeData, layer, sceneData).then(object => {
 
+    if (object instanceof Three.LOD) {
+      planData.sceneGraph.LODs[holeID] = object
+    }
+
     let pivot = new Three.Object3D();
     pivot.add(object);
 
@@ -374,6 +383,10 @@ function addLine(sceneData, planData, layer, lineID, catalog, linesActions) {
 
   return catalog.getElement(line.type).render3D(line, layer, sceneData).then(line3D => {
 
+    if (line3D instanceof Three.LOD) {
+      planData.sceneGraph.LODs[line.id] = line3D;
+    }
+
     let pivot = new Three.Object3D();
     pivot.add(line3D);
 
@@ -402,6 +415,11 @@ function addArea(sceneData, planData, layer, areaID, catalog, areaActions) {
   };
 
   return catalog.getElement(area.type).render3D(area, layer, sceneData).then(area3D => {
+
+    if (area3D instanceof Three.LOD) {
+      planData.sceneGraph.LODs[areaID] = area3D
+    }
+
     let pivot = new Three.Object3D();
     pivot.add(area3D);
     pivot.position.y = layer.altitude;
@@ -422,6 +440,10 @@ function addItem(sceneData, planData, layer, itemID, catalog, itemsActions) {
 
   return catalog.getElement(item.type).render3D(item, layer, sceneData).then(item3D => {
 
+    if (item3D instanceof Three.LOD) {
+      planData.sceneGraph.LODs[itemID] = item3D
+    }
+
     let pivot = new Three.Object3D();
     pivot.add(item3D);
 
