@@ -2,10 +2,11 @@ import Catalog from './catalog/catalog';
 import Translator from './translator/translator';
 import ToolbarButton from './components/toolbar/toolbar-button';
 import Ruler from './components/viewer2d/ruler';
-import * as Models from './models'
+import * as Models from './models';
 import State2DViewer from './components/viewer2d/state';
 import reducer from './reducers/reducer';
 import ReactPlanner from './react-planner';
+import Content from './components/content';
 import Plugins from './plugins/plugins';
 import WallFactory from './catalog/factories/wall-factory';
 import AreaFactory from './catalog/factories/area-factory';
@@ -22,8 +23,19 @@ import FormSelect from './components/style/form-select';
 import FormSlider from './components/style/form-slider';
 import FormSubmitButton from './components/style/form-submit-button';
 import FormTextInput from './components/style/form-text-input';
+import * as ReactPlannerConstants from './constants';
 import {VERSION} from './version';
 
+import ReactPlannerAreasReducer from './reducers/areas-reducer';
+import ReactPlannerHolesReducer from './reducers/holes-reducer';
+import ReactPlannerItemsReducer from './reducers/items-reducer';
+import ReactPlannerLinesReducer from './reducers/lines-reducer';
+import ReactPlannerProjectReducer from './reducers/project-reducer';
+import ReactPlannerSceneReducer from './reducers/scene-reducer';
+import ReactPlannerVerticesReducer from './reducers/vertices-reducer';
+import ReactPlannerViewer2dReducer from './reducers/viewer2d-reducer';
+import ReactPlannerViewer3dReducer from './reducers/viewer3d-reducer';
+
 let ElementsFactories = {WallFactory, AreaFactory};
 let StyleComponents = {
   Button, CancelButton, ContentContainer, ContentTitle, DeleteButton, FormBlock,
@@ -32,6 +44,18 @@ let StyleComponents = {
 
 console.info(`react-planner ${VERSION} started`); //MIT LICENSE COMPLIANT
 
+let ReactPlannerReducers = {
+  ReactPlannerAreasReducer,
+  ReactPlannerHolesReducer,
+  ReactPlannerItemsReducer,
+  ReactPlannerLinesReducer,
+  ReactPlannerProjectReducer,
+  ReactPlannerSceneReducer,
+  ReactPlannerVerticesReducer,
+  ReactPlannerViewer2dReducer,
+  ReactPlannerViewer3dReducer
+};
+
 export {
   Catalog,
   Translator,
@@ -41,7 +65,10 @@ export {
   State2DViewer,
   reducer,
   ReactPlanner,
+  Content as ReactPlannerContent,
   Plugins,
   ElementsFactories,
-  StyleComponents
+  StyleComponents,
+  ReactPlannerConstants,
+  ReactPlannerReducers
 };
